/*****************************************************************************
*   Presentation: DBA498 - Extended Events Deep Dive
*   FileName:  Demo 4 - SQLskills_TrackNetworkWaits_AppName.sql
*
*   Summary: Event Session for Extended Events Deep Dive
*   Summary: Create Event Session to track Network waits by client_app_name.
*
*   Date: October 3, 2011 
*
*   SQL Server Versions:
*         2008, 2008 R2
*         
******************************************************************************
*   Copyright (C) 2011 Jonathan M. Kehayias, SQLskills.com
*   All rights reserved. 
*
*   For more scripts and sample code, check out 
*      http://sqlskills.com/blogs/jonathan
*
*   You may alter this code for your own *non-commercial* purposes. You may
*   republish altered code as long as you include this copyright and give 
*	due credit. 
*
*
*   THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF 
*   ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED 
*   TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
*   PARTICULAR PURPOSE. 
*
******************************************************************************/

-- Lookup the MapKey for the NETWORK_IO Wait Type
SELECT map_key, map_value
FROM sys.dm_xe_map_values
WHERE map_value = 'NETWORK_IO'
  AND name = 'wait_types'
  

-- If the Event Session exists Drop it
IF EXISTS (SELECT 1 
			FROM sys.server_event_sessions 
			WHERE name = 'SQLskills_TrackNetworkWaits_AppName')
	DROP EVENT SESSION [SQLskills_TrackNetworkWaits_AppName] ON SERVER;

-- Create Event Session to find the database with most SP Recompile Events
CREATE EVENT SESSION [SQLskills_TrackNetworkWaits_AppName]
ON SERVER 
ADD EVENT  sqlos.wait_info
(    -- Capture the scheduler_id
    ACTION(sqlos.scheduler_id, sqlserver.client_app_name)
    WHERE
        (opcode = 1 --End Events Only
            AND duration > 0 AND (wait_type = 99) -- Network waits
		)            
)
ADD TARGET package0.asynchronous_bucketizer(
	SET filtering_event_name = 'sqlos.wait_info',
		source_type = 1, -- Action
		source = 'sqlserver.client_app_name')
WITH (EVENT_RETENTION_MODE=ALLOW_SINGLE_EVENT_LOSS,
      MAX_DISPATCH_LATENCY=5 SECONDS);
GO

-- Start the Event Session
ALTER EVENT SESSION [SQLskills_TrackNetworkWaits_AppName] 
ON SERVER 
STATE=START;
GO

-- Query target data
SELECT 
    n.value('(value)[1]', 'nvarchar(4000)') AS AppName,
    n.value('(@count)[1]', 'int') AS NetworkWaitCount
FROM
(SELECT CAST(target_data as XML) target_data
 FROM sys.dm_xe_sessions AS s 
 JOIN sys.dm_xe_session_targets t
     ON s.address = t.event_session_address
 WHERE s.name = 'SQLskills_TrackNetworkWaits_AppName'
   AND t.target_name = 'asynchronous_bucketizer') as tab
CROSS APPLY target_data.nodes('BucketizerTarget/Slot') as q(n)
ORDER BY AppName;

-- Drop the Event Session
DROP EVENT SESSION [SQLskills_TrackNetworkWaits_AppName]
ON SERVER;
