/*****************************************************************************
*   Presentation: DBA498 - Extended Events Deep Dive
*   FileName:  Demo 10 - NewInDenali.sql
*
*   Summary: Demonstrates what is new in SQL Server Denali CTP3
*
*   Date: October 7, 2011 
*
*   SQL Server Versions:
*         Denali CTP3
*         
******************************************************************************
*   Copyright (C) 2011 Jonathan M. Kehayias, SQLskills.com
*   All rights reserved. 
*
*   For more scripts and sample code, check out 
*      http://sqlskills.com/blogs/jonathan
*
*   You may alter this code for your own *non-commercial* purposes. You may
*   republish altered code as long as you include this copyright and give 
*	due credit. 
*
*
*   THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF 
*   ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED 
*   TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
*   PARTICULAR PURPOSE. 
*
******************************************************************************/

-- Map out Trace Events to Extended Events
SELECT 
	tc.name as trace_category,
	te.name as trace_event_name,
	txem.package_name+'.'+txem.xe_event_name as xevent_name
FROM sys.trace_events AS te
JOIN sys.trace_categories AS tc 
	ON te.category_id = tc.category_id
JOIN sys.trace_xe_event_map AS txem 
	ON te.trace_event_id = txem.trace_event_id
ORDER BY trace_category, trace_event_name

-- Map trace columns to Extended Events Actions
SELECT 
	tc.name as trace_column_name,
	txam.package_name+'.'+txam.xe_action_name AS xe_action_name
FROM sys.trace_columns AS tc
JOIN sys.trace_xe_action_map AS txam 
	ON tc.trace_column_id = txam.trace_column_id
ORDER BY trace_column_name



DECLARE @2008_XEventsObjects TABLE 
(package varchar(128), object varchar(128), type varchar(128))

INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_activation_stored_procedure_invoked', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_activation_task_limit_reached', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_activation_task_aborted', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_activation_task_started', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'buffer_manager_database_pages', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'buffer_manager_free_pages', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'buffer_manager_page_life_expectancy', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'buffer_manager_stolen_pages', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'buffer_manager_target_pages', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'buffer_manager_total_pages', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'buffer_node_database_pages', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'buffer_node_free_pages', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'buffer_node_page_life_expectancy', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'buffer_node_stolen_pages', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'buffer_node_target_pages', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'buffer_node_total_pages', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'buffer_partition_free_list_empty', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'buffer_partition_free_list_requests', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'buffer_partition_free_pages', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'catalog_metadata_cache_entry_added', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'catalog_metadata_cache_entry_removed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'catalog_metadata_cache_entry_pinned', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'catalog_metadata_cache_entry_unpinned', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'catalog_metadata_cache_hit', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'cursor_manager_cursor_begin', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'cursor_manager_cursor_end', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'cursor_manager_cursor_cache_hit', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'cursor_manager_cached_cursor_added', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'cursor_manager_cached_cursor_removed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'cursor_manager_cursor_memory_usage', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'cursor_manager_cursor_worktable_use_begin', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'cursor_manager_cursor_worktable_use_end', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'cursor_manager_cursor_plan_begin', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'cursor_manager_cursor_plan_end', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'database_transaction_begin', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'database_transaction_end', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'databases_backup_restore_throughput', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'databases_bulk_copy_rows', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'databases_bulk_copy_throughput', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'databases_data_file_size_changed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'databases_dbcc_logical_scan', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'databases_log_cache_hit', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'databases_log_cache_read', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'databases_log_file_size_changed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'databases_log_file_used_size_changed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'databases_log_flush_wait', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'databases_log_flush', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'databases_log_growth', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'databases_log_shrink', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'databases_log_truncation', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'databases_shrink_data_movement', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'locks_lock_timeouts_greater_than_0', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'locks_lock_timeouts', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'locks_lock_waits', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'plan_cache_cache_hit', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'user_settable', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'sql_statement_starting', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'sql_statement_completed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'sp_statement_starting', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'sp_statement_completed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'rpc_starting', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'rpc_completed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'ghost_cleanup', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'lock_acquired', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'lock_released', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'lock_deadlock', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'page_split', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'physical_page_read', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'physical_page_write', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'latch_suspend_begin', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'latch_suspend_end', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'latch_promoted', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'latch_demoted', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'plan_cache_cache_attempt', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'cursor_manager_cursor_cache_attempt', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'flush_file_buffers', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'file_read', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'file_written', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'file_read_completed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'file_write_completed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'checkpoint_begin', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'checkpoint_end', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'app_domain_ring_buffer_recorded', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'host_task_ring_buffer_recorded', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'error_ring_buffer_recorded', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'allocation_ring_buffer_recorded', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'errorlog_written', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'constant_page_corruption_detected', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'database_attached', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'database_detached', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'database_started', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'database_stopped', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'trace_flag_changed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'change_tracking_cleanup', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'error_reported', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'trace_print', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'deadlock_monitor_perf_stats', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'deadlock_monitor_mem_stats', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'deadlock_monitor_state_transition', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'deadlock_monitor_pmo_status', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'deadlock_monitor_serialized_local_wait_for_graph', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'buffer_pool_ring_buffer_recorded', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'page_compression_attempt_failed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'page_compression_tracing', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'long_io_detected', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'sort_statistics_tracing', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'sort_add_run_tracing', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'sort_state_change_tracing', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'sort_memory_grant_adjustment', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'sec_ekm_provider_called', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'module_start', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'module_end', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'filestream_file_io_request', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'filestream_file_io_response', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'filestream_file_io_failure', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'filestream_file_io_trace', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'filestream_file_io_dump', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'xml_deadlock_report', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'leaf_page_disfavored', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'prefetch_extent', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_deliverysm_event_end', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_timer_set', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_timer_reset', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_timer_fire', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_lazyflusher_submit', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_lazyflusher_processing_begin', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_lazyflusher_processing_end', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_timer_armed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_lazyflusher_remove', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_object_get', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_object_worktable_load_begin', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_object_worktable_load_end', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_object_worktable_save_begin', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_object_worktable_save_end', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_object_delete_begin', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_object_delete_end', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmitter_reclassification_phase_begin', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmitter_reclassification_phase_end', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_event_begin', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_action_fire', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_event_end', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_outgoing_connect_attempt', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_dns_lookup', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_winsock_connect_attempt', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_winsock_connect_fail', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_winsock_connect_success', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_acksm_event_begin', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_acksm_action_fire', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_acksm_event_end', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_close', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_read_complete', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_global_message_add', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_global_message_delete', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_message_add', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_message_delete', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_winsock_read', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_receive_io_complete', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_process_receive_control_block', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_delimit_message', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_write_complete', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_send_io_complete', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmitter_transport_stream_update', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmitter_destination_process_begin', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmitter_destination_process_end', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmitter_destination_process_sender_process', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmitter_destination_connect', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmitter_destination_event_fire', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmitter_destination_reference', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_deliverysm_event_begin', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_deliverysm_action_fire', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_process_boxcar', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_send', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmitter_destination_subscribe', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmitter_destination_unsubscribe', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmitter_service_create', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmitter_service_match', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_task_idempotent_submit', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_task_idempotent_invoke_begin', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_task_idempotent_invoke_end', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_incoming_connect_attempt', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmitter_service_send', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmitter_dialog_register', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmitter_dialog_unregister', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmitter_service_reclassify', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmitter_dialog_reclassify', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_flow_control', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_dialog_state_change', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_dialog_transmission_queue_enqueue', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_dialog_transmission_queue_dequeue', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'deprecation_announcement', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'deprecation_final_support', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'fastloadcontext_enabled', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'logreader_process_text_info', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'logreader_process_text_ptr', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'logreader_process_filestream_info', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'logreader_add_compensation_range', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'logreader_add_eor', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'logreader_add_tran_info', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'logreader_apply_filter_proc', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'cdc_session', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'cdc_error', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'group_commit_value_changed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'log_flush_requested', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'log_buffer_allocated', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'log_buffer_freed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'latch_acquire_time', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'failed_hresult', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'failed_hresult_msg', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'database_id', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'transaction_id', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'session_id', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'database_context', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'tsql_stack', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'sql_text', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'plan_handle', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'create_dump_single_thread', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'create_dump_all_threads', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'client_app_name', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'client_pid', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'client_hostname', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'nt_username', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'session_nt_username', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'username', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'session_resource_pool_id', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'session_resource_group_id', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'request_id', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'is_system', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'keyword_map', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'statement_state', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'file_io_mode', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'trace_flag_type', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'event_opcode', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'page_compression_failure_reason', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'change_tracking_status_id', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'buffer_pool_failure_type', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'sort_subevents', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_dns_lookup_result', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_acksm_event', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_acksm_state', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_acksm_action', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmitter_destination_event', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmitter_destination_state', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_dialog_state', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'group_commit_flush_reason', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'log_block_allocation_type', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'lock_resource_type', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'lock_owner_type', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'lock_mode', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'latch_mode', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'latch_class', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_task_handler_specialization', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_deliverysm_event', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_deliverysm_state', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_deliverysm_action', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_timer', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_object_worktable_load_result', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmission_object_state', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_state', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_event', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_action', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_endpoint_type', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_stream_update', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_stream_status', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transmitter_reclassification_phase', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_transport_connection_delimit_result', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_task_idempotent_type', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'broker_task_idempotent_state', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'fastloadctx_state', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'log_op', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'bstats_bits', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'database_id', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'transaction_id', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'session_id', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'client_app_name', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'client_pid', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'client_hostname', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'nt_domain', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'nt_user', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'session_nt_domain', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'session_nt_user', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'username', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'session_resource_pool_id', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'session_resource_group_id', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'request_id', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'is_system', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'equal_i_sql_unicode_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'not_equal_i_sql_unicode_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'less_than_i_sql_unicode_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'less_than_equal_i_sql_unicode_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'greater_than_i_sql_unicode_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'greater_than_equal_i_sql_unicode_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'equal_i_sql_ansi_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'not_equal_i_sql_ansi_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'less_than_i_sql_ansi_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'less_than_equal_i_sql_ansi_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'greater_than_i_sql_ansi_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'greater_than_equal_i_sql_ansi_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'equal_i_sql_unicode_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'not_equal_i_sql_unicode_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'less_than_i_sql_unicode_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'less_than_equal_i_sql_unicode_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'greater_than_i_sql_unicode_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'greater_than_equal_i_sql_unicode_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'equal_i_sql_ansi_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'not_equal_i_sql_ansi_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'less_than_i_sql_ansi_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'less_than_equal_i_sql_ansi_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'greater_than_i_sql_ansi_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'greater_than_equal_i_sql_ansi_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlserver', 'database_context', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'ex_terminator_called', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'crt_signal_abort_called', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'process_killed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'task_enqueued', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'thread_attached', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'thread_detached', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'scheduler_created', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'scheduler_destroyed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'async_io_requested', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'async_io_completed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'malloc_spy_memory_allocated', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'malloc_spy_memory_freed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'malloc_spy_corrupted_memory_detected', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'page_heap_memory_allocated', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'page_heap_memory_freed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'resource_monitor_ring_buffer_recorded', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'memory_broker_ring_buffer_recorded', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'scheduler_ring_buffer_recorded', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'exception_ring_buffer_recorded', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'scheduler_monitor_non_yielding_ring_buffer_recorded', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'scheduler_monitor_deadlock_ring_buffer_recorded', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'scheduler_monitor_system_health_ring_buffer_recorded', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'scheduler_monitor_non_yielding_iocp_ring_buffer_recorded', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'scheduler_monitor_non_yielding_rm_ring_buffer_recorded', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'spinlock_backoff', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'set_abort_callback_executed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'non_yielding_scheduler_callback_executed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'deadlock_scheduler_callback_executed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'non_yielding_iocp_listener_callback_executed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'idle_server_callback_executed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'memory_utilization_effect_callback_executed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'non_yielding_rm_callback_executed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'exit_routine_executed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'dump_exception_routine_executed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'crt_out_of_memory_routine_executed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'security_handler_routine_executed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'context_switch_callback_executed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'worker_state_callback_executed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'function_hook_changed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'scheduler_monitor_stalled_dispatcher_ring_buffer_recorded', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'node_created', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'cpu_config_changed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'multiple_tasks_enqueued', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'node_affinity_changed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'scheduler_online_state_changed', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'wait_info', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'wait_info_external', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'memory_node_oom_ring_buffer_recorded', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'assert_fired', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'sos_context', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'task_address', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'worker_address', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'task_time', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'task_elapsed_quantum', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'system_thread_id', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'scheduler_address', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'scheduler_id', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'cpu_id', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'node_id', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'task_resource_pool_id', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'task_resource_group_id', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'keyword_map', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'event_opcode', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'memory_allocation_type', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'resource_monitor_notification', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'mem_utilization_effect_state', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'assert_type', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'worker_type', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'wake_up_reason', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'effect_type', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'task_transition', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'worker_callback_type', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'function_hook_action', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'wait_types', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'memory_object_type', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'spinlock_types', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'task_address', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'worker_address', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'task_execution_time', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'task_elapsed_quantum', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'system_thread_id', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'scheduler_address', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'scheduler_id', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'cpu_id', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'node_id', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'task_resource_pool_id', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'task_resource_group_id', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('sqlos', 'sos_context', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'NullEvent', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'callstack', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'attach_activity_id', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'attach_activity_id_xfer', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'debug_break', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'collect_system_time', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'collect_cpu_cycle_time', 'action');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'etw_classic_sync_target', 'target');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'synchronous_bucketizer', 'target');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'asynchronous_bucketizer', 'target');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'asynchronous_file_target', 'target');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'pair_matching', 'target');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'synchronous_event_counter', 'target');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'ring_buffer', 'target');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'etw_level', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'etw_channel', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'etw_opcodes', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'log_messages', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'current_thread_id', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'counter', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'partitioned_counter', 'pred_source');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'equal_uint64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'not_equal_uint64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_uint64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_equal_uint64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_uint64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_equal_uint64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_max_uint64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_min_uint64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'equal_int64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'not_equal_int64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_int64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_equal_int64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_int64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_equal_int64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_max_int64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_min_int64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'equal_float64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'not_equal_float64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_float64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_equal_float64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_float64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_equal_float64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_max_float64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_min_float64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'equal_i_ansi_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'not_equal_i_ansi_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_i_ansi_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_equal_i_ansi_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_i_ansi_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_equal_i_ansi_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'equal_i_unicode_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'not_equal_i_unicode_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_i_unicode_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_equal_i_unicode_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_i_unicode_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_equal_i_unicode_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'equal_ansi_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'not_equal_ansi_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_ansi_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_equal_ansi_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_ansi_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_equal_ansi_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'equal_unicode_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'not_equal_unicode_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_unicode_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_equal_unicode_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_unicode_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_equal_unicode_string_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'equal_i_ansi_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'not_equal_i_ansi_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_i_ansi_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_equal_i_ansi_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_i_ansi_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_equal_i_ansi_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'equal_i_unicode_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'not_equal_i_unicode_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_i_unicode_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_equal_i_unicode_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_i_unicode_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_equal_i_unicode_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'equal_ansi_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'not_equal_ansi_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_ansi_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_equal_ansi_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_ansi_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_equal_ansi_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'equal_unicode_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'not_equal_unicode_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_unicode_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_equal_unicode_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_unicode_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_equal_unicode_string', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'equal_boolean', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'not_equal_boolean', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'equal_guid_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'not_equal_guid_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'equal_guid', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'not_equal_guid', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'equal_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'not_equal_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_equal_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_equal_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'greater_than_max_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'less_than_min_ptr', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'divides_by_uint64', 'pred_compare');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'null', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'int8', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'int16', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'int32', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'int64', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'uint8', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'uint16', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'uint32', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'uint64', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'float32', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'float64', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'cpu_cycle', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'filetime', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'ulong_ptr', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'ansi_string_ptr', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'unicode_string_ptr', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'guid_ptr', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'char', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'wchar', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'ansi_string', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'unicode_string', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'guid', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'binary_data', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'callstack', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'activity_id', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'activity_id_xfer', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('package0', 'boolean', 'type');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('SecAudit', 'audit_event', 'event');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('SecAudit', 'synchronous_security_audit_file_target', 'target');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('SecAudit', 'asynchronous_security_audit_file_target', 'target');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('SecAudit', 'synchronous_security_audit_event_log_target', 'target');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('SecAudit', 'asynchronous_security_audit_event_log_target', 'target');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('SecAudit', 'synchronous_security_audit_security_log_target', 'target');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('SecAudit', 'asynchronous_security_audit_security_log_target', 'target');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('SecAudit', 'failure_semantics', 'map');
INSERT INTO @2008_XEventsObjects (package, object, type) VALUES ('SecAudit', 'messages', 'map');


SELECT 
	p.name AS package_name, 
	o.name AS object_name, 
	object_type, 
	o.description
FROM sys.dm_xe_objects AS o
JOIN sys.dm_xe_packages AS p 
	ON o.package_guid = p.guid
WHERE NOT EXISTS (SELECT 1 
					FROM @2008_XEventsObjects 
					WHERE p.name = package COLLATE SQL_Latin1_General_CP1_CI_AS 
					  AND o.name = object COLLATE SQL_Latin1_General_CP1_CI_AS 
					  AND object_type = type COLLATE SQL_Latin1_General_CP1_CI_AS)