/*****************************************************************************
*   Presentation: DBA498 - Extended Events Deep Dive
*   FileName:  Demo 3a - Metadata Views.sql
*
*   Summary: Demonstrates how to query Extended Events Metadata information 
*            from the Metadata DMV's.
*
*   Date: September 7, 2011 
*
*   SQL Server Versions:
*         2008, 2008 R2
*         
******************************************************************************
*   Copyright (C) 2011 Jonathan M. Kehayias, SQLskills.com
*   All rights reserved. 
*
*   For more scripts and sample code, check out 
*      http://sqlskills.com/blogs/jonathan
*
*   You may alter this code for your own *non-commercial* purposes. You may
*   republish altered code as long as you include this copyright and give 
*	due credit. 
*
*
*   THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF 
*   ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED 
*   TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
*   PARTICULAR PURPOSE. 
*
******************************************************************************/

-- Extended Event Packages
SELECT *
FROM sys.dm_xe_packages p
WHERE (p.capabilities IS NULL OR p.capabilities & 1 = 0)

-- Event objects
SELECT p.name AS package_name,
       o.name AS event_name,
       o.description
FROM sys.dm_xe_packages AS p
JOIN sys.dm_xe_objects AS o 
     ON p.guid = o.package_guid
WHERE (p.capabilities IS NULL OR p.capabilities & 1 = 0)
  AND (o.capabilities IS NULL OR o.capabilities & 1 = 0)
  AND o.object_type = 'event'

-- Event Columns
SELECT oc.name AS column_name,
       oc.column_type AS column_type,
       oc.column_value AS column_value,
       oc.description AS column_description
FROM sys.dm_xe_packages AS p
JOIN sys.dm_xe_objects AS o 
     ON p.guid = o.package_guid
JOIN sys.dm_xe_object_columns AS oc 
     ON o.name = oc.object_name 
    AND o.package_guid = oc.object_package_guid
WHERE (p.capabilities IS NULL OR p.capabilities & 1 = 0)
  AND (o.capabilities IS NULL OR o.capabilities & 1 = 0)
  AND (oc.capabilities IS NULL OR oc.capabilities & 1 = 0)
  AND o.object_type = 'event'
  AND o.name = 'wait_info'

-- Look at available customizable columns
SELECT 
	o.name AS event_name, 
	oc.name AS column_name, 
	column_value, 
	oc.description
FROM sys.dm_xe_packages AS p
JOIN sys.dm_xe_objects AS o 
     ON p.guid = o.package_guid
JOIN sys.dm_xe_object_columns AS oc 
	ON o.package_guid = oc.object_package_guid
		AND o.name = oc.object_name
WHERE (p.capabilities IS NULL OR p.capabilities & 1 = 0)
  AND (o.capabilities IS NULL OR o.capabilities & 1 = 0)
  AND (oc.capabilities IS NULL OR oc.capabilities & 1 = 0)
  AND object_type = 'event'
  AND column_type = 'customizable'


-- Actions
SELECT p.name AS package_name,
       o.name AS action_name,
       o.description
FROM sys.dm_xe_packages AS p
JOIN sys.dm_xe_objects AS o 
     ON p.guid = o.package_guid
WHERE (p.capabilities IS NULL OR p.capabilities & 1 = 0)
  AND (o.capabilities IS NULL OR o.capabilities & 1 = 0)
  AND o.object_type = 'action' 

-- Targets
SELECT p.name AS package_name,
       o.name AS target_name,
       o.description
FROM sys.dm_xe_packages AS p
JOIN sys.dm_xe_objects AS o ON p.guid = o.package_guid
WHERE (p.capabilities IS NULL OR p.capabilities & 1 = 0)
  AND (o.capabilities IS NULL OR o.capabilities & 1 = 0)
  AND o.object_type = 'target'

-- Target Columns
SELECT oc.name AS column_name,
       oc.column_id,
       oc.type_name,
       oc.capabilities_desc,
       oc.description
FROM sys.dm_xe_packages AS p
JOIN sys.dm_xe_objects AS o 
     ON p.guid = o.package_guid
JOIN sys.dm_xe_object_columns AS oc 
     ON o.name = oc.object_name 
    AND o.package_guid = oc.object_package_guid
WHERE (p.capabilities IS NULL OR p.capabilities & 1 = 0)
  AND (o.capabilities IS NULL OR o.capabilities & 1 = 0)
  AND o.object_type = 'target'
  AND o.name = 'asynchronous_file_target'

-- State Data Predicates
SELECT p.name AS package_name,
       o.name AS source_name,
       o.description
FROM sys.dm_xe_objects AS o
JOIN sys.dm_xe_packages AS p 
     ON o.package_guid = p.guid
WHERE (p.capabilities IS NULL OR p.capabilities & 1 = 0)
  AND (o.capabilities IS NULL OR o.capabilities & 1 = 0)
  AND o.object_type = 'pred_source'

-- Comparison Predicates
SELECT p.name AS package_name,
       o.name AS source_name,
       o.description
FROM sys.dm_xe_objects AS o
JOIN sys.dm_xe_packages AS p 
     ON o.package_guid = p.guid
WHERE (p.capabilities IS NULL OR p.capabilities & 1 = 0)
  AND (o.capabilities IS NULL OR o.capabilities & 1 = 0)
  AND o.object_type = 'pred_compare'

-- Map Values
SELECT name, map_key, map_value 
FROM sys.dm_xe_map_values
WHERE name = 'wait_types'
