/*****************************************************************************
*   Presentation: DBA498 - Extended Events Deep Dive
*   FileName:  Demo 3b - Session Definition Views.sql
*
*   Summary: Demonstrates how to query Extended Events Metadata information 
*            from the Session Definition views.
*
*   Date: September 7, 2011 
*
*   SQL Server Versions:
*         2008, 2008 R2
*         
******************************************************************************
*   Copyright (C) 2011 Jonathan M. Kehayias, SQLskills.com
*   All rights reserved. 
*
*   For more scripts and sample code, check out 
*      http://sqlskills.com/blogs/jonathan
*
*   You may alter this code for your own *non-commercial* purposes. You may
*   republish altered code as long as you include this copyright and give 
*	due credit. 
*
*
*   THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF 
*   ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED 
*   TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
*   PARTICULAR PURPOSE. 
*
******************************************************************************/


-- Get events in a session
select sese.package AS event_package,
       sese.name AS event_name,
       sese.predicate AS event_predicate
FROM sys.server_event_sessions AS ses
JOIN sys.server_event_session_events AS sese
	 ON ses.event_session_id = sese.event_session_id
WHERE ses.name = 'system_health'

-- Get actions 
SELECT sese.package AS event_package,
       sese.name AS event_name,
       sese.predicate AS event_predicate,
       sesa.package AS action_package,
       sesa.name AS action_name
FROM sys.server_event_sessions AS ses
JOIN sys.server_event_session_events AS sese
	 ON ses.event_session_id = sese.event_session_id
JOIN sys.server_event_session_actions AS sesa
     ON ses.event_session_id = sesa.event_session_id
    AND sese.event_id = sesa.event_id
WHERE ses.name = 'system_health'


-- Get customizable column configuration
SELECT 
	ses.name as sesion_name,
	sese.package AS event_package,
	sese.name AS event_name,
	sese.predicate AS event_predicate,
	sesf.name AS customizable_column_name,
	sesf.value AS value
FROM sys.server_event_sessions AS ses
JOIN sys.server_event_session_events AS sese
	 ON ses.event_session_id = sese.event_session_id
JOIN sys.server_event_session_fields AS sesf
     ON ses.event_session_id = sesf.event_session_id
    AND sese.event_id = sesf.object_id
WHERE ses.name = 'system_health'


-- Get target information
SELECT ses.name AS session_name,
       sest.name AS target_name,
       sesf.name AS option_name,
       sesf.value AS option_value
FROM sys.server_event_sessions AS ses
JOIN sys.server_event_session_targets AS sest
         ON ses.event_session_id = sest.event_session_id
JOIN sys.server_event_session_fields AS sesf
     ON sest.event_session_id = sesf.event_session_id
    AND sest.target_id = sesf.object_id
WHERE ses.name = 'system_health'
