/*****************************************************************************
*   Presentation: DBA498 - Extended Events Deep Dive
*   FileName:  Demo 3c - Active Session DMVs.sql
*
*   Summary: Demonstrates how to query information about Active event 
*            sessions from the DMVs.
*
*   Date: September 7, 2011 
*
*   SQL Server Versions:
*         2008, 2008 R2
*         
******************************************************************************
*   Copyright (C) 2011 Jonathan M. Kehayias, SQLskills.com
*   All rights reserved. 
*
*   For more scripts and sample code, check out 
*      http://sqlskills.com/blogs/jonathan
*
*   You may alter this code for your own *non-commercial* purposes. You may
*   republish altered code as long as you include this copyright and give 
*	due credit. 
*
*
*   THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF 
*   ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED 
*   TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
*   PARTICULAR PURPOSE. 
*
******************************************************************************/


-- Event Information for a running session
SELECT s.name AS session_name,
       e.event_name AS event_name,
       e.event_predicate AS event_predicate,
       ea.action_name AS action_name
FROM sys.dm_xe_sessions AS s
JOIN sys.dm_xe_session_events AS e
     ON s.address = e.event_session_address
JOIN sys.dm_xe_session_event_actions AS ea
     ON e.event_session_address = ea.event_session_address
    AND e.event_name = ea.event_name

-- Target information for a running session
SELECT s.name AS session_name,
       t.target_name AS target_name,
       t.execution_count AS execution_count,
       t.execution_duration_ms AS execution_duration,
       cast(t.target_data as xml) AS target_data
FROM sys.dm_xe_sessions AS s
JOIN sys.dm_xe_session_targets AS t
     ON s.address = t.event_session_address

-- Configurable event and target column information
SELECT DISTINCT s.name AS session_name, 
       oc.object_name, 
       oc.object_type, 
       oc.column_name, 
       oc.column_value
FROM sys.dm_xe_sessions AS s
JOIN sys.dm_xe_session_targets AS t
     ON s.address = t.event_session_address
JOIN sys.dm_xe_session_events AS e
     ON s.address = e.event_session_address
JOIN sys.dm_xe_session_object_columns AS oc
     ON s.address = oc.event_session_address
    AND ((oc.object_type = 'target' AND t.target_name = oc.object_name) 
       OR (oc.object_type = 'event' AND e.event_name = oc.object_name))
