﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Data.SqlClient;
using Microsoft.SqlServer.XEvent.Linq;
using System.Diagnostics;
using System.Threading;

namespace XEventsStreamingProvider
{
    class Program
    {
        static void Main(string[] args)
        {
            SQLWorker w = new SQLWorker();

            Console.ReadKey();
            w.RequestStop();
            w.Thread.Join();
        }
    }

    public class SQLWorker
    {
        QueryableXEventData<PublishedEvent> stream;
        Thread t;
        private volatile bool workerCanceled = false;

        public SQLWorker()
        {
            SqlConnectionStringBuilder scsb = new SqlConnectionStringBuilder();
            scsb.ApplicationName = "SQLSentry";
            scsb.DataSource = "ALWAYSON-SQL1";
            scsb.InitialCatalog = "master";
            scsb.IntegratedSecurity = true;

            SqlConnection conn = new SqlConnection(scsb.ConnectionString);
            conn.Open();

            SqlCommand cmd = conn.CreateCommand();
            cmd.CommandText = @"IF NOT EXISTS (SELECT 1 FROM sys.server_event_sessions WHERE name = 'SQLSentry_TopStatements')
    BEGIN
        -- Session does not exist, so create it.
        CREATE EVENT SESSION SQLSentry_TopStatements
        ON SERVER
        ADD EVENT sqlserver.database_file_size_change(
	        ACTION (sqlserver.client_app_name, sqlserver.client_hostname, sqlserver.database_id,
			        sqlserver.server_principal_name, sqlserver.session_id)),
        ADD EVENT sqlserver.rpc_completed(
	        ACTION (sqlserver.client_app_name, sqlserver.client_hostname, sqlserver.database_id,
			        sqlserver.nt_username, sqlserver.server_principal_name, sqlserver.session_id,
			        sqlserver.transaction_id)
	        WHERE (duration > 5000000)),
        ADD EVENT sqlserver.sp_statement_completed(
	        ACTION (sqlserver.client_app_name, sqlserver.client_hostname, sqlserver.database_id,
			        sqlserver.nt_username, sqlserver.server_principal_name, sqlserver.session_id,
			        sqlserver.transaction_id, sqlserver.tsql_frame)
	        WHERE (duration > 5000000)),
        ADD EVENT sqlserver.sql_batch_completed(
	        ACTION (sqlserver.client_app_name, sqlserver.client_hostname, sqlserver.database_id,
			        sqlserver.nt_username, sqlserver.server_principal_name, sqlserver.session_id,
			        sqlserver.transaction_id)
	        WHERE (duration > 5000000)),
        ADD EVENT sqlserver.sql_statement_completed(
	        ACTION (sqlserver.client_app_name, sqlserver.client_hostname, sqlserver.database_id,
			        sqlserver.nt_username, sqlserver.server_principal_name, sqlserver.session_id,
			        sqlserver.transaction_id, sqlserver.tsql_frame)
	        WHERE (duration > 5000000)),
        ADD EVENT sqlserver.xml_deadlock_report(
	        ACTION (sqlserver.client_app_name, sqlserver.client_hostname, sqlserver.client_pid,
			        sqlserver.database_id, sqlserver.nt_username, sqlserver.server_principal_name,
			        sqlserver.session_id));
        
        -- Now start the session
        ALTER EVENT SESSION SQLSentry_TopStatements
        ON SERVER
        STATE=START;
    END
ELSE
    BEGIN
        -- Session exists, is it running?
        IF NOT EXISTS (SELECT 1 FROM sys.dm_xe_sessions WHERE name = 'SQLSentry_TopStatements')
            BEGIN
                -- Session is not running so start it.
                ALTER EVENT SESSION SQLSentry_TopStatements
                ON SERVER
                STATE=START;
            END
    END";
            cmd.ExecuteNonQuery();

            stream = new QueryableXEventData<PublishedEvent>(
                        scsb.ConnectionString,
                        "SQLSentry_TopStatements",
                        EventStreamSourceOptions.EventStream,
                        EventStreamCacheOptions.DoNotCache);

            t = new Thread(ReadEventStream);
            t.Start();
        }

        public Thread Thread
        {
            get
            {
                return t;
            }
        }


        public void RequestStop()
        {
            workerCanceled = true;
        }
  
        public void ReadEventStream()
        {
                foreach (PublishedEvent pe in stream.EventProvider)
                {
                    ThreadPool.QueueUserWorkItem(new WaitCallback(ProcessEvent), pe);
                    if (workerCanceled)
                         break;
                }
        }

        public void ProcessEvent(object sender)
        {
            Console.WriteLine(((PublishedEvent)sender).Name);
        }


    }
}
